
from logging import Logger
from logging import getLogger

from umlextensions.BaseExtension import BaseExtension


class BaseInputExtension(BaseExtension):
    """
    Base class for extensions that can convert foreign structured
    data into UML Diagrams.  Examples include but are not limited to:
        * DTDs
        * Java code
        * Python code
    """
    def __init__(self):
        super().__init__()
        self.logger: Logger = getLogger(__name__)




from logging import Logger
from logging import getLogger


class ExtensionManager:
    """
    Manages the various extensions provided by module
        InputExtension
        OutputExtension
        ToolExtension
    """
    def __init__(self):
        self.logger: Logger = getLogger(__name__)




from logging import Logger
from logging import getLogger


class BaseExtension:
    """
    Contains common behavior and attributes for the various
    types of extensions
    """
    def __init__(self):
        self._baseLogger: Logger = getLogger(__name__)




from abc import ABC


class IExtensionAdapter(ABC):
    """
    The UML Diagrammer implements this interface in order to
    provide services to the extensions
    """
    def __init__(self):
        pass




from logging import Logger
from logging import getLogger

from umlextensions.BaseExtension import BaseExtension


class BaseToolExtension(BaseExtension):
    """
    Base class for extensions that can manipulate UML diagrams.  Examples,
    include but are not limited to:

        * Various layouts (Sugiyama, Orthogonal, Force Directed
        * Arranging non crossing links
        * Arranging orthogonal links
    """
    def __init__(self):
        super().__init__()
        self.logger: Logger = getLogger(__name__)
